<?php

namespace App\Controller\Admin;

use App\Entity\Fridge;
use App\Entity\FridgeProductLine;
use App\Entity\Product;
use App\Entity\QuantityUnit;
use App\Entity\Recipe;
use App\Entity\RecipeProductLine;
use App\Entity\User;
use EasyCorp\Bundle\EasyAdminBundle\Config\Dashboard;
use EasyCorp\Bundle\EasyAdminBundle\Config\MenuItem;
use EasyCorp\Bundle\EasyAdminBundle\Controller\AbstractDashboardController;
use EasyCorp\Bundle\EasyAdminBundle\Router\AdminUrlGenerator;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class DashboardController extends AbstractDashboardController
{
    public function __construct(private AdminUrlGenerator $adminUrlGenerator)
    {
    }

    #[Route('/admin', name: 'admin')]
    public function index(): Response
    {
        return $this->redirect($this->adminUrlGenerator->setController(ProductCrudController::class)->generateUrl());
    }

    public function configureDashboard(): Dashboard
    {
        return Dashboard::new()
            ->setTitle('IceCold');
    }

    public function configureMenuItems(): iterable
    {
        yield MenuItem::linktoRoute('Back to home', 'fas fa-home', 'home');

        yield MenuItem::section('Products', 'fas fa-folder-open');
        yield MenuItem::linkToDashboard('Dashboard', 'fa fa-home');
        yield MenuItem::linkToCrud('Products', 'fas fa-list', Product::class);
        yield MenuItem::linkToCrud('Quantity units', 'fas fa-list', QuantityUnit::class);

        yield MenuItem::section('Product lists', 'fas fa-folder-open');
        yield MenuItem::linkToCrud('Recipes', 'fas fa-list', Recipe::class);
        yield MenuItem::linkToCrud('Recipe product lines', 'fas fa-list', RecipeProductLine::class);
        yield MenuItem::linkToCrud('Fridges', 'fas fa-list', Fridge::class);
        yield MenuItem::linkToCrud('Fridge product lines', 'fas fa-list', FridgeProductLine::class);

        yield MenuItem::section('Administration', 'fas fa-folder-open');
        yield MenuItem::linkToCrud('User', 'fas fa-list', User::class);
    }
}
